<?php

function theme_poll_results($variables) {
  $build = [];

  if ($variables['poll']) {
    /** @var \TwilioPoll $poll */
    $poll = $variables['poll'];
    $poll_sms_id = $poll->getSmsId();

    if ($variables['heading']) {
      $build['heading'] = [
        '#markup' => '<h3>' . $variables['heading'] . '</h3>',
      ];
    }

    $build['#sms_number'] = $twilio_number = variable_get('twilio_number', 'N/A');
    $message_vars = [
      '@sms_id'       => $poll_sms_id,
      '@phone_number' => $twilio_number,
      '@sms_uri' => "sms://{$twilio_number}",
    ];
    $build['message'] = [
      '#markup' => t('Send <span class="poll-sms-id">@sms_id</span> followed by one of the following options to <a href="@sms_uri">@phone_number</a>', $message_vars),
    ];

    $build['answers'] = [
      '#theme'        => 'poll_result_answers',
      '#poll_answers' => [],
    ];

    $poll_answers = $variables['poll']->getOptions();
    $poll_results = twilio_poll_votes_get_by_poll($variables['poll']);

    /** @var \TwilioPollOption $poll_option */
    foreach ($poll_answers as $poll_option) {
      $build['answers']['#poll_answers'][$poll_option->getId()] = [
        '#theme'       => 'poll_result_bar',
        '#poll_option' => $poll_option,
      ];
    }

    foreach ($poll_results as $poll_result) {
      $match = [];
      // Check if a "value" is either a percent or a count
      if (preg_match('/^(?:option\-)(?<id>\d+)(?<is_percent>\-percent)?$/', $poll_result['function'], $match)) {
        $answer_id = $match['id'];
        if (isset($match['is_percent'])) {
          $build['answers']['#poll_answers'][$answer_id]['#vote_percent'] = $poll_result['value'];
        }
        else {
          $build['answers']['#poll_answers'][$answer_id]['#vote_count'] = $poll_result['value'];
        }
      }
      elseif ($poll_result['function'] === 'total') {
        // Special treatment for the Totals.
        $build['answers']['#votes_count'] = $poll_result['value'];
      }
    }

    // drupal_add_js(drupal_get_path('module', 'twilio_poll') . '/twilio_poll.js', ['every_page' => FALSE]);
    drupal_add_css(drupal_get_path('module', 'twilio_poll') . '/twilio_poll.css', ['every_page' => FALSE]);
  }

  return render($build);
}
